Module client

Module client 

Modules

header
HTTP header types

Structs

Client
A wrapper around Reqwest client to give additional features when used with the request functions.
ClientConfig
Configures the HTTP client.
HeaderValue
Represents an HTTP header field value.
HttpData
Represents the data from HTTP responses.
RequestOptions
Used by the request functions.
ReqwestClient
An asynchronous Client to make Requests with.
ReqwestClientConfig
Configures the HTTP client.
ReqwestError
The Errors that may occur when processing a Request.
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).

Functions

create_client
Creates a wrapped HTTP client. The wrapped client holds its own connection pools, so in many uses cases creating only one client per process is necessary.
create_reqwest_client
Creates an HTTP client using Reqwest. The Reqwest client holds its own connection pools, so in many uses cases creating only one client per process is necessary.